%==========================================================================
% The function defines the ODE of a tractor with the states X(the
% x-position), Y(the y-position) and beta(the orientation). The input is
% the steering angle alpha
% The nonlinear ODE is given by:
%   dX/dt = V * cos(beta)
%   dY/dt = V * sin(beta)
%   dbeta/dt = V/L * tan(alpha)
% 
% Input Parameter: state x, control input u; both are column vectors 
% Output Parameter: dx/dt; is a column vector
%
% AUTHOR: Joerg Fischer, Lukas Klar
% Systems control and optimization laboratory, 
% Department of Microsystems Engineering (IMTEK),
% University of Freiburg
%==========================================================================
function [ xdot ] = tractor_ode_nl(x, u)
    % Parameter definition
    V = 5; % m/s
    L = 3; % m
    % ODE
    xdot = [V * cos(x(3));
            V * sin(x(3));
            V / L * tan(u)];
end